@@ -17,47 +17,64 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
+// own
 #include "kmahjonggtileset.h"
-#include "libkmahjongg_debug.h"
 
-#include <KLocalizedString>
-#include <kconfig.h>
-#include <kconfiggroup.h>
-#include <qimage.h>
-#include <qsvgrenderer.h>
+// STL
+#include <cstdlib>
+
+// Qt
+#include <QFile>
+#include <QImage>
+#include <QMap>
 #include <QPainter>
 #include <QPixmapCache>
-#include <QFile>
-#include <QMap>
 #include <QStandardPaths>
+#include <QSvgRenderer>
 
-#include <stdlib.h>
+// KDE
+#include <KConfig>
+#include <KConfigGroup>
+#include <KLocalizedString>
+
+// LibKMahjongg
+#include "libkmahjongg_debug.h"
 
 class KMahjonggTilesetMetricsData
 {
-  public:
-    short lvloffx;   // used for 3D indentation, x value
-    short lvloffy;   // used for 3D indentation, y value
-    short w;    // tile width ( +border +shadow)
-    short h;    // tile height ( +border +shadow)
-    short fw;   // face width
-    short fh;   // face height
+public:
+    short lvloffx; // used for 3D indentation, x value
+    short lvloffy; // used for 3D indentation, y value
+    short w; // tile width ( +border +shadow)
+    short h; // tile height ( +border +shadow)
+    short fw; // face width
+    short fh; // face height
 
     KMahjonggTilesetMetricsData()
-     : lvloffx(0), lvloffy(0), w(0), h(0), fw(0), fh(0)
-    {}
+        : lvloffx(0)
+        , lvloffy(0)
+        , w(0)
+        , h(0)
+        , fw(0)
+        , fh(0)
+    {
+    }
 };
 
 class KMahjonggTilesetPrivate
 {
-  public:
-    KMahjonggTilesetPrivate() : isSVG(false), graphicsLoaded(false) {}
+public:
+    KMahjonggTilesetPrivate()
+        : isSVG(false)
+        , graphicsLoaded(false)
+    {
+    }
     QList<QString> elementIdTable;
     QMap<QString, QString> authorproperties;
 
     KMahjonggTilesetMetricsData originaldata;
     KMahjonggTilesetMetricsData scaleddata;
-    QString filename;  // cache the last file loaded to save reloading it
+    QString filename; // cache the last file loaded to save reloading it
     QString graphicspath;
 
     QSvgRenderer svg;
@@ -73,14 +90,16 @@ KMahjonggTileset::KMahjonggTileset()
     buildElementIdTable();
 
     static bool _inited = false;
-    if (_inited)
+    if (_inited) {
         return;
+    }
     _inited = true;
 }
 
 // ---------------------------------------------------------
 
-KMahjonggTileset::~KMahjonggTileset() {
+KMahjonggTileset::~KMahjonggTileset()
+{
     delete d;
 }
 
@@ -88,11 +107,11 @@ void KMahjonggTileset::updateScaleInfo(short tilew, short tileh)
 {
     d->scaleddata.w = tilew;
     d->scaleddata.h = tileh;
-    double ratio = ((qreal) d->scaleddata.w) / ((qreal) d->originaldata.w);
-    d->scaleddata.lvloffx = (short) (d->originaldata.lvloffx * ratio);
-    d->scaleddata.lvloffy = (short) (d->originaldata.lvloffy * ratio);
-    d->scaleddata.fw = (short) (d->originaldata.fw * ratio);
-    d->scaleddata.fh = (short) (d->originaldata.fh * ratio);
+    double ratio = (static_cast<qreal>(d->scaleddata.w)) / (static_cast<qreal>(d->originaldata.w));
+    d->scaleddata.lvloffx = static_cast<short>(d->originaldata.lvloffx * ratio);
+    d->scaleddata.lvloffy = static_cast<short>(d->originaldata.lvloffy * ratio);
+    d->scaleddata.fw = static_cast<short>(d->originaldata.fw * ratio);
+    d->scaleddata.fh = static_cast<short>(d->originaldata.fh * ratio);
 }
 
 QSize KMahjonggTileset::preferredTileSize(const QSize & boardsize, int horizontalCells, int verticalCells)
@@ -108,20 +127,20 @@ QSize KMahjonggTileset::preferredTileSize(const QSize & boardsize, int horizonta
     qreal floatw = d->originaldata.w;
     qreal floath = d->originaldata.h;
 
-    if ((fullw/fullh)>(bw/bh)) {
+    if ((fullw / fullh) > (bw / bh)) {
         //space will be left on height, use width as limit
-        aspectratio = bw/fullw;
+        aspectratio = bw / fullw;
     } else {
-        aspectratio = bh/fullh;
+        aspectratio = bh / fullh;
     }
     newtilew = aspectratio * floatw;
     newtileh = aspectratio * floath;
-    return QSize((short)newtilew, (short)newtileh);
+    return QSize(static_cast<short>(newtilew), static_cast<short>(newtileh));
 }
 
 bool KMahjonggTileset::loadDefault()
 {
-    QString idx = QLatin1String( "default.desktop" );
+    QString idx = QLatin1String("default.desktop");
 
     QString tilesetPath = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "kmahjongglib/tilesets/" + idx);
     qCDebug(LIBKMAHJONGG_LOG) << "Inside LoadDefault(), located path at" << tilesetPath;
@@ -131,7 +150,7 @@ bool KMahjonggTileset::loadDefault()
     return loadTileset(tilesetPath);
 }
 
-QString KMahjonggTileset::authorProperty(const QString &key) const
+QString KMahjonggTileset::authorProperty(const QString & key) const
 {
     return d->authorproperties[key];
 }
@@ -158,12 +177,12 @@ short KMahjonggTileset::levelOffsetY() const
 
 short KMahjonggTileset::qWidth() const
 {
-    return (short) (d->scaleddata.fw / 2.0);
+    return static_cast<short>(d->scaleddata.fw / 2.0);
 }
 
 short KMahjonggTileset::qHeight() const
 {
-    return (short) (d->scaleddata.fh / 2.0);
+    return static_cast<short>(d->scaleddata.fh / 2.0);
 }
 
 QString KMahjonggTileset::path() const
@@ -174,10 +193,8 @@ QString KMahjonggTileset::path() const
 #define kTilesetVersionFormat 1
 
 // ---------------------------------------------------------
-bool KMahjonggTileset::loadTileset( const QString & tilesetPath)
+bool KMahjonggTileset::loadTileset(const QString & tilesetPath)
 {
-
-    QImage qiTiles;
     //qCDebug(LIBKMAHJONGG_LOG) << "Attempting to load .desktop at" << tilesetPath;
 
     //clear our properties map
@@ -186,20 +203,20 @@ bool KMahjonggTileset::loadTileset( const QString & tilesetPath)
     // verify if it is a valid file first and if we can open it
     QFile tilesetfile(tilesetPath);
     if (!tilesetfile.open(QIODevice::ReadOnly)) {
-        return (false);
+        return false;
     }
     tilesetfile.close();
 
     KConfig tileconfig(tilesetPath, KConfig::SimpleConfig);
     KConfigGroup group = tileconfig.group("KMahjonggTileset");
 
-    d->authorproperties.insert(QLatin1String( "Name" ), group.readEntry("Name"));// Returns translated data
-    d->authorproperties.insert(QLatin1String( "Author" ), group.readEntry("Author"));
-    d->authorproperties.insert(QLatin1String( "Description" ), group.readEntry("Description"));
-    d->authorproperties.insert(QLatin1String( "AuthorEmail" ), group.readEntry("AuthorEmail"));
+    d->authorproperties.insert(QLatin1String("Name"), group.readEntry("Name")); // Returns translated data
+    d->authorproperties.insert(QLatin1String("Author"), group.readEntry("Author"));
+    d->authorproperties.insert(QLatin1String("Description"), group.readEntry("Description"));
+    d->authorproperties.insert(QLatin1String("AuthorEmail"), group.readEntry("AuthorEmail"));
 
     //Version control
-    int tileversion = group.readEntry("VersionFormat",0);
+    int tileversion = group.readEntry("VersionFormat", 0);
     //Format is increased when we have incompatible changes, meaning that older clients are not able to use the remaining information safely
     if (tileversion > kTilesetVersionFormat) {
         return false;
@@ -209,11 +226,12 @@ bool KMahjonggTileset::loadTileset( const QString & tilesetPath)
 
     d->graphicspath = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "kmahjongglib/tilesets/" + graphName);
     //qCDebug(LIBKMAHJONGG_LOG) << "Using tileset at" << d->graphicspath;
-    //d->filename = graphicsPath;
 
     //only SVG for now
     d->isSVG = true;
-    if (d->graphicspath.isEmpty()) return (false);
+    if (d->graphicspath.isEmpty()) {
+        return false;
+    }
 
     d->originaldata.w = group.readEntry("TileWidth", 30);
     d->originaldata.h = group.readEntry("TileHeight", 50);
@@ -226,31 +244,15 @@ bool KMahjonggTileset::loadTileset( const QString & tilesetPath)
     d->graphicsLoaded = false;
     d->filename = tilesetPath;
 
- /*   if (d->isSVG) {
-        //really?
-        d->svg.load(graphicsPath);
-        if (d->svg.isValid()) {
-            d->filename = tilesetPath;
-            //invalidate our global cache
-            QPixmapCache::clear();
-
-            d->isSVG = true;
-            reloadTileset(QSize(d->originaldata.w, d->originaldata.h));
-        } else {
-            return( false );
-        }
-    } else {
-        //TODO add support for png??
-        return false;
-    }*/
-
-    return( true );
+    return true;
 }
 
 // ---------------------------------------------------------
 bool KMahjonggTileset::loadGraphics()
 {
-    if (d->graphicsLoaded == true) return (true) ;
+    if (d->graphicsLoaded) {
+        return true;
+    }
     if (d->isSVG) {
         //really?
         d->svg.load(d->graphicspath);
@@ -260,79 +262,82 @@ bool KMahjonggTileset::loadGraphics()
             d->graphicsLoaded = true;
             reloadTileset(QSize(d->originaldata.w, d->originaldata.h));
         } else {
-            return( false );
+            return false;
         }
     } else {
         //TODO add support for png??
         return false;
     }
 
-    return( true );
+    return true;
 }
 
 // ---------------------------------------------------------
-bool KMahjonggTileset::reloadTileset( const QSize & newTilesize)
+bool KMahjonggTileset::reloadTileset(const QSize & newTilesize)
 {
-    QString tilesetPath = d->filename;
-
-    if (QSize(d->scaleddata.w, d->scaleddata.h) == newTilesize) return false;
+    if (QSize(d->scaleddata.w, d->scaleddata.h) == newTilesize) {
+        return false;
+    }
 
     if (d->isSVG) {
         if (d->svg.isValid()) {
             updateScaleInfo(newTilesize.width(), newTilesize.height());
             //rendering will be done when needed, automatically using the global cache
         } else {
-            return( false );
+            return false;
         }
     } else {
         //TODO add support for png???
         return false;
     }
 
-    return( true );
+    return true;
 }
 
-void KMahjonggTileset::buildElementIdTable() {
+void KMahjonggTileset::buildElementIdTable()
+{
     //Build a list for faster lookup of element ids, mapped to the enumeration used by GameData and BoardWidget
     //Unselected tiles
-    for (short idx=1; idx<=4; idx++) {
-        d->elementIdTable.append(QString::fromLatin1( "TILE_%1").arg(idx));
+    for (short idx = 1; idx <= 4; idx++) {
+        d->elementIdTable.append(QString::fromLatin1("TILE_%1").arg(idx));
     }
     //Selected tiles
-    for (short idx=1; idx<=4; idx++) {
-        d->elementIdTable.append(QString::fromLatin1( "TILE_%1_SEL").arg(idx));
+    for (short idx = 1; idx <= 4; idx++) {
+        d->elementIdTable.append(QString::fromLatin1("TILE_%1_SEL").arg(idx));
     }
     //now faces
-    for (short idx=1; idx<=9; idx++) {
-        d->elementIdTable.append(QString::fromLatin1( "CHARACTER_%1").arg(idx));
+    for (short idx = 1; idx <= 9; idx++) {
+        d->elementIdTable.append(QString::fromLatin1("CHARACTER_%1").arg(idx));
     }
-    for (short idx=1; idx<=9; idx++) {
-        d->elementIdTable.append(QString::fromLatin1( "BAMBOO_%1").arg(idx));
+    for (short idx = 1; idx <= 9; idx++) {
+        d->elementIdTable.append(QString::fromLatin1("BAMBOO_%1").arg(idx));
     }
-    for (short idx=1; idx<=9; idx++) {
-        d->elementIdTable.append(QString::fromLatin1( "ROD_%1").arg(idx));
+    for (short idx = 1; idx <= 9; idx++) {
+        d->elementIdTable.append(QString::fromLatin1("ROD_%1").arg(idx));
     }
-    for (short idx=1; idx<=4; idx++) {
-        d->elementIdTable.append(QString::fromLatin1( "SEASON_%1").arg(idx));
+    for (short idx = 1; idx <= 4; idx++) {
+        d->elementIdTable.append(QString::fromLatin1("SEASON_%1").arg(idx));
     }
-    for (short idx=1; idx<=4; idx++) {
-        d->elementIdTable.append(QString::fromLatin1( "WIND_%1").arg(idx));
+    for (short idx = 1; idx <= 4; idx++) {
+        d->elementIdTable.append(QString::fromLatin1("WIND_%1").arg(idx));
     }
-    for (short idx=1; idx<=3; idx++) {
-        d->elementIdTable.append(QString::fromLatin1( "DRAGON_%1").arg(idx));
+    for (short idx = 1; idx <= 3; idx++) {
+        d->elementIdTable.append(QString::fromLatin1("DRAGON_%1").arg(idx));
     }
-    for (short idx=1; idx<=4; idx++) {
-        d->elementIdTable.append(QString::fromLatin1( "FLOWER_%1").arg(idx));
+    for (short idx = 1; idx <= 4; idx++) {
+        d->elementIdTable.append(QString::fromLatin1("FLOWER_%1").arg(idx));
     }
 }
 
-QString KMahjonggTileset::pixmapCacheNameFromElementId(const QString & elementid) {
-    return authorProperty(QLatin1String( "Name" ))+ elementid + QString::fromLatin1( "W%1H%2").arg(d->scaleddata.w).arg(d->scaleddata.h);
+QString KMahjonggTileset::pixmapCacheNameFromElementId(const QString & elementid)
+{
+    return authorProperty(QLatin1String("Name")) + elementid + QString::fromLatin1("W%1H%2").arg(d->scaleddata.w).arg(d->scaleddata.h);
 }
 
-QPixmap KMahjonggTileset::renderElement(short width, short height, const QString & elementid) {
-    ////qCDebug(LIBKMAHJONGG_LOG) << "render element" << elementid << width << height;
-    QImage qiRend(QSize(width, height),QImage::Format_ARGB32_Premultiplied);
+QPixmap KMahjonggTileset::renderElement(short width, short height, const QString & elementid)
+{
+    //qCDebug(LIBKMAHJONGG_LOG) << "render element" << elementid << width << height;
+    QImage qiRend(QSize(width, height), QImage::Format_ARGB32_Premultiplied);
     qiRend.fill(0);
 
     if (d->svg.isValid()) {
@@ -342,9 +347,10 @@ QPixmap KMahjonggTileset::renderElement(short width, short height, const QString
     return QPixmap::fromImage(qiRend);
 }
 
-QPixmap KMahjonggTileset::selectedTile(int num) {
+QPixmap KMahjonggTileset::selectedTile(int num)
+{
     QPixmap pm;
-    QString elemId = d->elementIdTable.at(num+4);//selected offset in our idtable;
+    QString elemId = d->elementIdTable.at(num + 4); //selected offset in our idtable;
     if (!QPixmapCache::find(pixmapCacheNameFromElementId(elemId), &pm)) {
         //use tile size
         pm = renderElement(d->scaleddata.w, d->scaleddata.h, elemId);
@@ -353,7 +359,8 @@ QPixmap KMahjonggTileset::selectedTile(int num) {
     return pm;
 }
 
-QPixmap KMahjonggTileset::unselectedTile(int num) {
+QPixmap KMahjonggTileset::unselectedTile(int num)
+{
     QPixmap pm;
     QString elemId = d->elementIdTable.at(num);
     if (!QPixmapCache::find(pixmapCacheNameFromElementId(elemId), &pm)) {
@@ -364,14 +371,15 @@ QPixmap KMahjonggTileset::unselectedTile(int num) {
     return pm;
 }
 
-QPixmap KMahjonggTileset::tileface(int num) {
+QPixmap KMahjonggTileset::tileface(int num)
+{
     QPixmap pm;
     if ((num + 8) >= d->elementIdTable.count()) {
         //qCDebug(LIBKMAHJONGG_LOG) << "Client asked for invalid tileface id";
         return pm;
     }
 
-    QString elemId = d->elementIdTable.at(num + 8);//tileface offset in our idtable;
+    QString elemId = d->elementIdTable.at(num + 8); //tileface offset in our idtable;
     if (!QPixmapCache::find(pixmapCacheNameFromElementId(elemId), &pm)) {
         //use face size
         pm = renderElement(d->scaleddata.fw, d->scaleddata.fh, elemId);
@@ -379,4 +387,3 @@ QPixmap KMahjonggTileset::tileface(int num) {
     }
     return pm;
 }
-
